summary | shortlog | log | commit | commitdiff | tree
raw | patch | inline | side by side (parent: 56248c5)
raw | patch | inline | side by side (parent: 56248c5)
author | Junio C Hamano <junkio@cox.net> | |
Wed, 1 Mar 2006 04:26:25 +0000 (20:26 -0800) | ||
committer | Junio C Hamano <junkio@cox.net> | |
Wed, 1 Mar 2006 06:38:40 +0000 (22:38 -0800) |
This is passed down to git-apply to override the built-in
default and per-repository configuration at runtime.
Signed-off-by: Junio C Hamano <junkio@cox.net>
default and per-repository configuration at runtime.
Signed-off-by: Junio C Hamano <junkio@cox.net>
git-am.sh | patch | blob | history |
diff --git a/git-am.sh b/git-am.sh
index 7cc4ae5a30ed3a56cff9def63e351f957cad6666..ab133fbd51308da26665abf34d169d9c1044c0d4 100755 (executable)
--- a/git-am.sh
+++ b/git-am.sh
}
prec=4
-dotest=.dotest sign= utf8= keep= skip= interactive= resolved= binary=
+dotest=.dotest sign= utf8= keep= skip= interactive= resolved= binary= ws=
while case "$#" in 0) break;; esac
do
--sk|--ski|--skip)
skip=t; shift ;;
+ --whitespace=*)
+ ws=$1; shift ;;
+
--)
shift; break ;;
-*)
exit 1
}
# -b, -s, -u and -k flags are kept for the resuming session after
# a patch failure.
# -3 and -i can and must be given when resuming.
echo "$binary" >"$dotest/binary"
+ echo " $ws" >"$dotest/whitespace"
echo "$sign" >"$dotest/sign"
echo "$utf8" >"$dotest/utf8"
echo "$keep" >"$dotest/keep"
then
keep=-k
fi
+ws=`cat "$dotest/whitespace"`
if test "$(cat "$dotest/sign")" = t
then
SIGNOFF=`git-var GIT_COMMITTER_IDENT | sed -e '
case "$resolved" in
'')
- git-apply $binary --index "$dotest/patch"
+ git-apply $binary --index $ws "$dotest/patch"
apply_status=$?
;;
t)
@@
exit 1
}
- # -b, -s, -u and -k flags are kept for the resuming session after
- # a patch failure.
+ # -b, -s, -u, -k and --whitespace flags are kept for the
+ # resuming session after a patch failure.
# -3 and -i can and must be given when resuming.
echo "$binary" >"$dotest/binary"